mod block;

use std::thread;
use std::time::Duration;

use itertools::Itertools;
use xcb::x;

use block::*;

fn main() -> xcb::Result<()> {
    let (conn, screen_num) = xcb::Connection::connect(None)?;

    // Fetch the `x::Setup` and get the main `x::Screen` object.
    let setup = conn.get_setup();
    let screen = setup.roots().nth(screen_num as usize).unwrap();

    let blocks: Vec<Box<dyn Block>> = vec![
        Box::new(Music {}),
        Box::new(Volume {}),
        Box::new(Temp {}),
        //Box::new(Mem {}),
        Box::new(Date {
            format: "%A %d %B | %H:%M".to_string(),
        }),
    ];

    loop {
        let status_bar: String = blocks
            .iter()
            .map(|block| block.display())
            .intersperse(" | ".to_string())
            .collect();

        let status_bar = format!(" {} ", status_bar);

        conn.send_request(&x::ChangeProperty {
            mode: x::PropMode::Replace,
            window: screen.root(),
            property: x::ATOM_WM_NAME,
            r#type: x::ATOM_STRING,
            data: status_bar.as_bytes(),
        });

        conn.flush()?;

        thread::sleep(Duration::from_secs(1));
    }
}
